
//-----------------------------------------------------------------------------
// This is a part of the Microsoft Source Code Samples.
// Copyright (C) 1993-1995 Microsoft Corporation.
// All rights reserved.
//
// This source code is only intended as a supplement to
// Microsoft Development Tools and/or WinHelp documentation.
// See these sources for detailed information regarding the
// Microsoft samples programs.
//-----------------------------------------------------------------------------

/****************************************************************************\
*  dialogs.c -- sample program demonstrating Windows Sockets APIs.
*
*  Handles the dialog boxes for the WSOCK sample.
*
****************************************************************************/

#include <windows.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "resource.h"

static unsigned long   dot2ip(char *dot);

#define IP_ERROR    0xFFFEFFFFL
extern	HWND	    hwndMain;			// our main window handle

unsigned long	Ip;
int		Port = 16;
int		Baud = 7;
int		Bit = 3;
int		Stop = 0;
int		Parity = 0;
int		Flow = 1;

static char ip[80] = "192.168.1.100";
static char port[80];
static char *baud[] = { "300",
			"600",
			"1200",
			"2400",
			"4800",
			"7200",
			"9600",
			"19200",
			"38400",
			"57600",
			"115200",
			"203400",
			"460800",
			NULL};
static char *bit[] = {	"5",
			"6",
			"7",
			"8",
			NULL};
static char *stop[] = { "1",
			"2",
			NULL};
static char *parity[]={ "NONE",
			"EVEN",
			"ODD",
			NULL};
static char *flow[] = { "NONE",
			"H/W",
			"S/W",
			NULL};

LRESULT APIENTRY About(
	HWND hDlg,		  /* window handle of the dialog box */
	UINT message,		  /* type of message		     */
	UINT wParam,		  /* message-specific information    */
	LONG lParam)
{
     switch (message) {
	case WM_COMMAND:			 /* message: received a command */
	  if (LOWORD(wParam) == IDOK		 /* "OK" box selected?          */
		|| LOWORD(wParam) == IDCANCEL) { /* System menu close command?	*/
			EndDialog(hDlg, TRUE);	 /* Exits the dialog box	*/
	  return (TRUE);	/* WM_COMMAND */
     }
     break;
   } /* End switch message */
   return (FALSE);			      /* Didn't process a message    */
   UNREFERENCED_PARAMETER(lParam);
}

LRESULT APIENTRY Config(
	HWND hDlg,		  /* window handle of the dialog box */
	UINT message,		  /* type of message		     */
	UINT wParam,		  /* message-specific information    */
	LONG lParam)
{
	int		i;
	char		buf[128];
	unsigned long	iip;

	switch (message) {
	    case WM_INITDIALOG: 		    /* message: initialize dialog box */
		i = 0;
		while (baud[i] != NULL) {
		    SendDlgItemMessage(hDlg,IDM_BAUD,
			CB_ADDSTRING,0, (LPARAM) (LPSTR) baud[i]);
		    i++;
		}
		SendDlgItemMessage(hDlg,IDM_BAUD,
			CB_SETCURSEL,(WPARAM) Baud,  (LPARAM) (LPSTR) 0);
		i = 0;
		while (bit[i] != NULL) {
		    SendDlgItemMessage(hDlg,IDM_BIT,
			CB_ADDSTRING,0, (LPARAM) (LPSTR) bit[i]);
		    i++;
		}
		SendDlgItemMessage(hDlg,IDM_BIT,
			CB_SETCURSEL,(WPARAM) Bit,  (LPARAM) (LPSTR) 0);
		i = 0;
		while (parity[i] != NULL) {
		    SendDlgItemMessage(hDlg,IDM_PARITY,
			CB_ADDSTRING,0, (LPARAM) (LPSTR) parity[i]);
		    i++;
		}
		SendDlgItemMessage(hDlg,IDM_PARITY,
			CB_SETCURSEL,(WPARAM) Parity,  (LPARAM) (LPSTR) 0);
		i = 0;
		while (stop[i] != NULL) {
		    SendDlgItemMessage(hDlg,IDM_STOP,
			CB_ADDSTRING,0, (LPARAM) (LPSTR) stop[i]);
		    i++;
		}
		SendDlgItemMessage(hDlg,IDM_STOP,
			CB_SETCURSEL,(WPARAM) Stop,  (LPARAM) (LPSTR) 0);
		i = 0;
		while (flow[i] != NULL) {
		    SendDlgItemMessage(hDlg,IDM_FLOW,
			CB_ADDSTRING,0, (LPARAM) (LPSTR) flow[i]);
		    i++;
		}
		SendDlgItemMessage(hDlg,IDM_FLOW,
			CB_SETCURSEL,(WPARAM) Flow,  (LPARAM) (LPSTR) 0);
		wsprintf(port,"%d",Port);
		SetDlgItemText(hDlg,IDM_PORT,port);
		SetDlgItemText(hDlg,IDM_IP,ip);
		Ip = dot2ip(ip);
		return (TRUE);
	    case WM_COMMAND:			     /* message: received a command */
		switch(LOWORD(wParam)) {
		    case IDM_SAVE :
			GetDlgItemText(hDlg,IDM_IP,buf,sizeof(buf));
			iip = dot2ip(buf);
			if (iip == IP_ERROR) {
			    MessageBox(hwndMain,"Invalid IP address!",
				    NULL,MB_OK | MB_ICONHAND);
			    break;
			}
			strcpy(ip,buf);
			Ip = iip;

			GetDlgItemText(hDlg,IDM_PORT,buf,sizeof(buf));
			i = atoi(buf);
			if ((i <= 0) || (i > 16)) {
			    MessageBox(hwndMain,"Invalid PORT (1 - 16) !",
				    NULL,MB_OK | MB_ICONHAND);
			    break;
			}
			strcpy(port,buf);
			Port = i;
			Baud = SendDlgItemMessage(hDlg,IDM_BAUD,
			    CB_GETCURSEL,(WPARAM) 0,  (LPARAM) (LPSTR) 0);
			Bit  = SendDlgItemMessage(hDlg,IDM_BIT,
			    CB_GETCURSEL,(WPARAM) 0,  (LPARAM) (LPSTR) 0);
			Parity = SendDlgItemMessage(hDlg,IDM_PARITY,
			    CB_GETCURSEL,(WPARAM) 0,  (LPARAM) (LPSTR) 0);
			Stop = SendDlgItemMessage(hDlg,IDM_STOP,
			    CB_GETCURSEL,(WPARAM) 0,  (LPARAM) (LPSTR) 0);
			Flow = SendDlgItemMessage(hDlg,IDM_FLOW,
			    CB_GETCURSEL,(WPARAM) 0,  (LPARAM) (LPSTR) 0);
		    case IDM_ABORT	    :
		    case IDCANCEL	    :
			EndDialog(hDlg, TRUE);	 /* Exits the dialog box	*/
			break;
		    default		    :
			return FALSE;
		}
		return (TRUE);	      /* WM_COMMAND */
	    default :
		 break;
	}
	return (FALSE); 			   /* Didn't process a message    */
	UNREFERENCED_PARAMETER(lParam);
}

/*
 *	Convert dot notation to IP address
 */
static u_long  dot2ip(dot)
	char	*dot;
{
	u_long	ip;
	u_char	*c;
	int	i, d;

	c = (u_char *)&ip;
	for (i = 4; i-- > 0; ) {
		d = *dot++ - '0';
		if (d < 0 || d > 9)
			return IP_ERROR;
		while (*dot >= '0' && *dot <= '9') {
			d = d * 10 + *dot++ - '0';
			if (d > 255)
				return IP_ERROR;
		}
		*c++ = d;
		if (*dot++ != '.')
			break;
	}
	if (*--dot || i)
		return IP_ERROR;
	return ip;
}

void	ConfigInit()
{
	Ip = dot2ip(ip);
}
